@@ -20,7 +20,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA  02111-1307, USA.
  *
- * $Id: newbucket.cxx,v 1.5 2005/10/25 13:48:58 ehofman Exp $
+ * $Id: newbucket.cxx,v 1.3 2004/11/19 21:44:16 curt Exp $
  **************************************************************************/
 
 
@@ -208,7 +208,7 @@ double SGBucket::get_width_m() const {
     double clat_rad = clat * SGD_DEGREES_TO_RADIANS;
     double cos_lat = cos( clat_rad );
     double local_radius = cos_lat * SG_EQUATORIAL_RADIUS_M;
-    double local_perimeter = local_radius * SGD_2PI;
+    double local_perimeter = 2.0 * local_radius * SGD_PI;
     double degree_width = local_perimeter / 360.0;
 
     return sg_bucket_span( get_center_lat() ) * degree_width;
@@ -217,7 +217,7 @@ double SGBucket::get_width_m() const {
 
 // return height of the tile in meters
 double SGBucket::get_height_m() const {
-    double perimeter = SG_EQUATORIAL_RADIUS_M * SGD_2PI;
+    double perimeter = 2.0 * SG_EQUATORIAL_RADIUS_M * SGD_PI;
     double degree_height = perimeter / 360.0;
 
     return SG_BUCKET_SPAN * degree_height;
@@ -271,32 +271,16 @@ void sgBucketDiff( const SGBucket& b1, const SGBucket& b2, int *dx, int *dy ) {
 #endif
 
     // longitude difference
-    double diff_lon=0.0;
-    double span=0.0;
-
-    SGBucket tmp_bucket;
-    // To handle crossing the bucket size boundary
-    //  we need to account for different size buckets.
-
-    if ( sg_bucket_span(c1_lat) <= sg_bucket_span(c2_lat) )
-    {
+    double c1_lon = b1.get_center_lon();
+    double c2_lon = b2.get_center_lon();
+    double diff_lon = c2_lon - c1_lon;
+    double span;
+    if ( sg_bucket_span(c1_lat) <= sg_bucket_span(c2_lat) ) {
 	span = sg_bucket_span(c1_lat);
     } else {
 	span = sg_bucket_span(c2_lat);
     }
 
-    diff_lon = b2.get_center_lon() - b1.get_center_lon();
-
-    if (diff_lon <0.0)
-    {
-       diff_lon -= b1.get_width()*0.5 + b2.get_width()*0.5 - span;
-    } 
-    else
-    {
-       diff_lon += b1.get_width()*0.5 + b2.get_width()*0.5 - span;
-    }
-
-
 #ifdef HAVE_RINT
     *dx = (int)rint( diff_lon / span );
 #else
