@@ -14,12 +14,11 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Library General Public License for more details.
 //
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA  02111-1307, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: constants.h,v 1.5 2005/10/27 08:21:00 ehofman Exp $
+// $Id: constants.h,v 1.9 2006-03-08 18:16:08 mfranz Exp $
 
 /** \file constants.h
  * Various constant definitions.
@@ -32,9 +31,6 @@
 
 #include <simgear/compiler.h>
 
-#ifdef _MSC_VER
-#  define  _USE_MATH_DEFINES
-#endif
 #ifdef SG_HAVE_STD_INCLUDES
 #  include <cmath>
 #else
