@@ -16,9 +16,9 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: metar.cxx,v 1.7 2005/10/06 09:45:36 ehofman Exp $
+// $Id: metar.cxx,v 1.13 2006-03-08 18:16:08 mfranz Exp $
 
 /**
  * @file metar.cxx
@@ -107,7 +107,7 @@ SGMetar::SGMetar(const string& m, const string& proxy, const string& port,
 	scanType();
 	if (!scanId() || !scanDate()) {
 		delete[] _data;
-		throw sg_io_exception("metar data bogus (" + _url + ')');
+		throw sg_io_exception("metar data bogus ", sg_location(_url));
 	}
 	scanModifier();
 
@@ -133,7 +133,7 @@ SGMetar::SGMetar(const string& m, const string& proxy, const string& port,
 
 	if (_grpcount < 4) {
 		delete[] _data;
-		throw sg_io_exception("metar data incomplete (" + _url + ')');
+		throw sg_io_exception("metar data incomplete ", sg_location(_url));
 	}
 
 	_url = "";
@@ -196,7 +196,7 @@ char *SGMetar::loadData(const char *id, const string& proxy, const string& port,
 	sock->set_timeout(10000);
 	if (!sock->open(SG_IO_OUT)) {
 		delete sock;
-		throw sg_io_exception("cannot connect to " + host);
+		throw sg_io_exception("cannot connect to ", sg_location(host));
 	}
 
 	string get = "GET ";
@@ -218,7 +218,7 @@ char *SGMetar::loadData(const char *id, const string& proxy, const string& port,
 	while ((i = sock->readline(buf, buflen))) {
 		if (i <= 2 && isspace(buf[0]) && (!buf[1] || isspace(buf[1])))
 			break;
-		if (!strncmp(buf, "X-MetarProxy: ", 9))
+		if (!strncmp(buf, "X-MetarProxy: ", 13))
 			_x_proxy = true;
 	}
 	if (i) {
@@ -233,7 +233,8 @@ char *SGMetar::loadData(const char *id, const string& proxy, const string& port,
 	char *b = buf;
 	scanBoundary(&b);
 	if (*b == '<')
-		throw sg_io_exception("no metar data available from " + _url);
+		throw sg_io_exception("no metar data available from ", 
+				sg_location(_url));
 
 	char *metar = new char[strlen(b) + 2];	// make room for " \0"
 	strcpy(metar, b);
@@ -608,56 +609,56 @@ bool SGMetar::scanRwyVisRange()
 
 
 static const struct Token special[] = {
-	"NSW",	"no significant weather",
-	"VCSH",	"showers in the vicinity",
-	"VCTS",	"thunderstorm in the vicinity",
-	0, 0
+	{ "NSW",  "no significant weather" },
+	{ "VCSH", "showers in the vicinity" },
+	{ "VCTS", "thunderstorm in the vicinity" },
+	{ 0, 0 }
 };
 
 
 static const struct Token description[] = {
-	"SH",	"showers of",
-	"TS",	"thunderstorm with",
-	"BC",	"patches of",
-	"BL",	"blowing",
-	"DR",	"low drifting",
-	"FZ",	"freezing",
-	"MI",	"shallow",
-	"PR",	"partial",
-	0, 0
+	{ "SH", "showers of" },
+	{ "TS", "thunderstorm with" },
+	{ "BC", "patches of" },
+	{ "BL", "blowing" },
+	{ "DR", "low drifting" },
+	{ "FZ", "freezing" },
+	{ "MI", "shallow" },
+	{ "PR", "partial" },
+	{ 0, 0 }
 };
 
 
 static const struct Token phenomenon[] = {
-	"DZ",	"drizzle",
-	"GR",	"hail",
-	"GS",	"small hail and/or snow pellets",
-	"IC",	"ice crystals",
-	"PE",	"ice pellets",
-	"RA",	"rain",
-	"SG",	"snow grains",
-	"SN",	"snow",
-	"UP",	"unknown precipitation",
-	"BR",	"mist",
-	"DU",	"widespread dust",
-	"SG",	"fog",
-	"SGBR",	"fog bank",
-	"FU",	"smoke",
-	"HZ",	"haze",
-	"PY",	"spray",
-	"SA",	"sand",
-	"VA",	"volcanic ash",
-	"DS",	"duststorm",
-	"FC",	"funnel cloud/tornado waterspout",
-	"PO",	"well-developed dust/sand whirls",
-	"SQ",	"squalls",
-	"SS",	"sandstorm",
-	"UP",	"unknown",	// ... due to failed automatic acquisition
-	0, 0
+	{ "DZ",   "drizzle" },
+	{ "GR",   "hail" },
+	{ "GS",   "small hail and/or snow pellets" },
+	{ "IC",   "ice crystals" },
+	{ "PE",   "ice pellets" },
+	{ "RA",   "rain" },
+	{ "SG",   "snow grains" },
+	{ "SN",   "snow" },
+	{ "UP",   "unknown precipitation" },
+	{ "BR",   "mist" },
+	{ "DU",   "widespread dust" },
+	{ "FG",   "fog" },
+	{ "FGBR", "fog bank" },
+	{ "FU",   "smoke" },
+	{ "HZ",   "haze" },
+	{ "PY",   "spray" },
+	{ "SA",   "sand" },
+	{ "VA",   "volcanic ash" },
+	{ "DS",   "duststorm" },
+	{ "FC",   "funnel cloud/tornado waterspout" },
+	{ "PO",   "well-developed dust/sand whirls" },
+	{ "SQ",   "squalls" },
+	{ "SS",   "sandstorm" },
+	{ "UP",   "unknown" },	// ... due to failed automatic acquisition
+	{ 0, 0 }
 };
 
 
-// (+|-|VC)?(NSW|MI|PR|BC|DR|BL|SH|TS|FZ)?((DZ|RA|SN|SG|IC|PE|GR|GS|UP){0,3})(BR|SG|FU|VA|DU|SA|HZ|PY|PO|SQ|FC|SS|DS){0,3}
+// (+|-|VC)?(NSW|MI|PR|BC|DR|BL|SH|TS|FZ)?((DZ|RA|SN|SG|IC|PE|GR|GS|UP){0,3})(BR|FG|FU|VA|DU|SA|HZ|PY|PO|SQ|FC|SS|DS){0,3}
 bool SGMetar::scanWeather()
 {
 	char *m = _m;
@@ -713,26 +714,26 @@ bool SGMetar::scanWeather()
 
 
 static const struct Token cloud_types[] = {
-	"AC",	 "altocumulus",
-	"ACC",	 "altocumulus castellanus",
-	"ACSL",	 "altocumulus standing lenticular",
-	"AS",	 "altostratus",
-	"CB",	 "cumulonimbus",
-	"CBMAM", "cumulonimbus mammatus",
-	"CC",	 "cirrocumulus",
-	"CCSL",	 "cirrocumulus standing lenticular",
-	"CI",	 "cirrus",
-	"CS",	 "cirrostratus",
-	"CU",	 "cumulus",
-	"CUFRA", "cumulus fractus",
-	"NS",	 "nimbostratus",
-	"SAC",	 "stratoaltocumulus",		// guessed
-	"SC",	 "stratocumulus",
-	"SCSL",	 "stratocumulus standing lenticular",
-	"ST",	 "stratus",
-	"STFRA", "stratus fractus",
-	"TCU",	 "towering cumulus",
-	0, 0
+	{ "AC",    "altocumulus" },
+	{ "ACC",   "altocumulus castellanus" },
+	{ "ACSL",  "altocumulus standing lenticular" },
+	{ "AS",    "altostratus" },
+	{ "CB",    "cumulonimbus" },
+	{ "CBMAM", "cumulonimbus mammatus" },
+	{ "CC",    "cirrocumulus" },
+	{ "CCSL",  "cirrocumulus standing lenticular" },
+	{ "CI",    "cirrus" },
+	{ "CS",    "cirrostratus" },
+	{ "CU",    "cumulus" },
+	{ "CUFRA", "cumulus fractus" },
+	{ "NS",    "nimbostratus" },
+	{ "SAC",   "stratoaltocumulus" },		// guessed
+	{ "SC",    "stratocumulus" },
+	{ "SCSL",  "stratocumulus standing lenticular" },
+	{ "ST",    "stratus" },
+	{ "STFRA", "stratus fractus" },
+	{ "TCU",   "towering cumulus" },
+	{ 0, 0 }
 };
 
 
@@ -957,11 +958,13 @@ bool SGMetar::scanRunwayReport()
 			m++;
 		else
 			return false;
+
 		if (*m == '1' || *m == '2' || *m == '5' || *m == '9') {	// extent of deposit
 			r._extent = *m - '0';
 			r._extent_string = runway_deposit_extent[*m - '0'];
 		} else if (*m != '/')
 			return false;
+
 		m++;
 		i = -1;
 		if (!strncmp(m, "//", 2))
@@ -970,7 +973,7 @@ bool SGMetar::scanRunwayReport()
 			return false;
 
 		if (i == 0)
-			r._depth = 0.5;					// < 1 mm deep (let's say 0.5 :-)
+			r._depth = 0.0005;				// < 1 mm deep (let's say 0.5 :-)
 		else if (i > 0 && i <= 90)
 			r._depth = i / 1000.0;				// i mm deep
 		else if (i >= 92 && i <= 98)
@@ -996,6 +999,7 @@ bool SGMetar::scanRunwayReport()
 		return false;
 
 	_runways[id]._deposit = r._deposit;
+	_runways[id]._deposit_string = r._deposit_string;
 	_runways[id]._extent = r._extent;
 	_runways[id]._extent_string = r._extent_string;
 	_runways[id]._depth = r._depth;
@@ -1075,13 +1079,13 @@ bool SGMetar::scanTrendForecast()
 
 // (BLU|WHT|GRN|YLO|AMB|RED)
 static const struct Token colors[] = {
-	"BLU", "Blue",		// 2500 ft,  8.0 km
-	"WHT", "White",		// 1500 ft,  5.0 km
-	"GRN", "Green",		//  700 ft,  3.7 km
-	"YLO", "Yellow",	//  300 ft,  1.6 km
-	"AMB", "Amber",		//  200 ft,  0.8 km
-	"RED", "Red",		// <200 ft, <0.8 km
-	0, 0
+	{ "BLU", "Blue" },      // 2500 ft,  8.0 km
+	{ "WHT", "White" },     // 1500 ft,  5.0 km
+	{ "GRN", "Green" },     //  700 ft,  3.7 km
+	{ "YLO", "Yellow" },	//  300 ft,  1.6 km
+	{ "AMB", "Amber" },     //  200 ft,  0.8 km
+	{ "RED", "Red" },       // <200 ft, <0.8 km
+	{ 0, 0 }
 };
 
 
