@@ -16,16 +16,17 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 //
-
 #ifdef HAVE_CONFIG_H
 #  include <simgear_config.h>
 #endif
 
 #include <plib/sg.h>
 #include <simgear/constants.h>
+#include <simgear/structure/SGReferenced.hxx>
+#include <simgear/structure/SGSharedPtr.hxx>
 #include <simgear/math/sg_random.h>
 #include <simgear/math/sg_geodesy.hxx>
 #include <simgear/math/point3d.hxx>
@@ -33,6 +34,7 @@
 #include <simgear/sound/soundmgr_openal.hxx>
 #include <simgear/scene/sky/cloudfield.hxx>
 #include <simgear/scene/sky/newcloud.hxx>
+#include <simgear/props/props.hxx>
 #include "visual_enviro.hxx"
 
 #include <vector>
@@ -50,6 +52,85 @@ typedef struct {
 static float rainpos[MAX_RAIN_SLICE];
 #define MAX_LT_TREE_SEG	400
 
+#define DFL_MIN_LIGHT 0.35
+sgVec3 SGEnviro::min_light = {DFL_MIN_LIGHT, DFL_MIN_LIGHT, DFL_MIN_LIGHT};
+#define DFL_STREAK_BRIGHT_NEARMOST_LAYER 0.9
+SGfloat SGEnviro::streak_bright_nearmost_layer = DFL_STREAK_BRIGHT_NEARMOST_LAYER;
+#define DFL_STREAK_BRIGHT_FARMOST_LAYER 0.5
+SGfloat SGEnviro::streak_bright_farmost_layer = DFL_STREAK_BRIGHT_FARMOST_LAYER;
+#define DFL_STREAK_PERIOD_MAX 2.5
+SGfloat SGEnviro::streak_period_max = DFL_STREAK_PERIOD_MAX;
+#define DFL_STREAK_PERIOD_CHANGE_PER_KT 0.005
+SGfloat SGEnviro::streak_period_change_per_kt = DFL_STREAK_PERIOD_CHANGE_PER_KT;
+#define DFL_STREAK_PERIOD_MIN 1.0
+SGfloat SGEnviro::streak_period_min = DFL_STREAK_PERIOD_MIN;
+#define DFL_STREAK_LENGTH_MIN 0.03
+SGfloat SGEnviro::streak_length_min = DFL_STREAK_LENGTH_MIN;
+#define DFL_STREAK_LENGTH_CHANGE_PER_KT 0.0005
+SGfloat SGEnviro::streak_length_change_per_kt = DFL_STREAK_LENGTH_CHANGE_PER_KT;
+#define DFL_STREAK_LENGTH_MAX 0.1
+SGfloat SGEnviro::streak_length_max = DFL_STREAK_LENGTH_MAX;
+#define DFL_STREAK_COUNT_MIN 40
+int SGEnviro::streak_count_min = DFL_STREAK_COUNT_MIN;
+#define DFL_STREAK_COUNT_MAX 190
+#if (DFL_STREAK_COUNT_MAX > MAX_RAIN_SLICE)
+#error "Bad default!"
+#endif
+int SGEnviro::streak_count_max = DFL_STREAK_COUNT_MAX;
+#define DFL_CONE_BASE_RADIUS 15.0
+SGfloat SGEnviro::cone_base_radius = DFL_CONE_BASE_RADIUS;
+#define DFL_CONE_HEIGHT 30.0
+SGfloat SGEnviro::cone_height = DFL_CONE_HEIGHT;
+
+
+void SGEnviro::config(const SGPropertyNode* n)
+{
+	if (!n)
+		return;
+
+	const float ml = n->getFloatValue("min-light", DFL_MIN_LIGHT);
+	sgSetVec3(min_light, ml, ml, ml);
+
+	streak_bright_nearmost_layer = n->getFloatValue(
+			"streak-brightness-nearmost-layer",
+			DFL_STREAK_BRIGHT_NEARMOST_LAYER);
+	streak_bright_farmost_layer = n->getFloatValue(
+			"streak-brightness-farmost-layer",
+			DFL_STREAK_BRIGHT_FARMOST_LAYER);
+
+	streak_period_max = n->getFloatValue(
+			"streak-period-max",
+			DFL_STREAK_PERIOD_MAX);
+	streak_period_min = n->getFloatValue(
+			"streak-period-min",
+			DFL_STREAK_PERIOD_MIN);
+	streak_period_change_per_kt = n->getFloatValue(
+			"streak-period-change-per-kt",
+			DFL_STREAK_PERIOD_CHANGE_PER_KT);
+
+	streak_length_max = n->getFloatValue(
+			"streak-length-max",
+			DFL_STREAK_LENGTH_MAX);
+	streak_length_min = n->getFloatValue(
+			"streak-length-min",
+			DFL_STREAK_LENGTH_MIN);
+	streak_length_change_per_kt = n->getFloatValue(
+			"streak-length-change-per-kt",
+			DFL_STREAK_LENGTH_CHANGE_PER_KT);
+
+	streak_count_min = n->getIntValue(
+			"streak-count-min", DFL_STREAK_COUNT_MIN);
+	streak_count_max = n->getIntValue(
+			"streak-count-max", DFL_STREAK_COUNT_MAX);
+	if (streak_count_max > MAX_RAIN_SLICE)
+		streak_count_max = MAX_RAIN_SLICE;
+
+	cone_base_radius = n->getFloatValue(
+			"cone-base-radius", DFL_CONE_BASE_RADIUS);
+	cone_height = n->getFloatValue("cone_height", DFL_CONE_HEIGHT);
+}
+
+
 /**
  * A class to render lightnings.
  */
@@ -84,23 +165,23 @@ static list_of_lightning lightnings;
 
 SGEnviro sgEnviro;
 
-SGEnviro::SGEnviro(void) :
+SGEnviro::SGEnviro() :
 	view_in_cloud(false),
-	turbulence_enable_state(false),
 	precipitation_enable_state(true),
+	precipitation_density(100.0),
+	precipitation_max_alt(0.0),
+	turbulence_enable_state(false),
+	last_cloud_turbulence(0.0),
+	cloud_turbulence(0.0),
 	lightning_enable_state(false),
+	elapsed_time(0.0),
+	dt(0.0),
 	soundMgr(NULL),
 	snd_active(false),
 	snd_dist(0.0),
-	last_cloud_turbulence(0.0),
-	cloud_turbulence(0.0),
-	elapsed_time(0.0),
-	dt(0.0),
 	min_time_before_lt(0.0),
 	fov_width(55.0),
-	fov_height(55.0),
-	precipitation_max_alt(0.0),
-	precipitation_density(100.0)
+	fov_height(55.0)
 
 {
 	for(int i = 0; i < MAX_RAIN_SLICE ; i++)
@@ -245,7 +326,7 @@ void SGEnviro::setLight(sgVec4 adj_fog_color) {
 	}
 }
 
-void SGEnviro::callback_cloud(float heading, float alt, float radius, int familly, float dist, int cloudId) {
+void SGEnviro::callback_cloud(float heading, float alt, float radius, int family, float dist, int cloudId) {
 	// send data to wx radar
 	// compute turbulence
 	// draw precipitation
@@ -255,7 +336,7 @@ void SGEnviro::callback_cloud(float heading, float alt, float radius, int famill
 	// http://www.pilotfriend.com/flight_training/weather/THUNDERSTORM%20HAZARDS1.htm
 	double turbulence = 0.0;
 	if( dist < radius * radius * 2.25f ) {
-		switch(familly) {
+		switch(family) {
 			case SGNewCloud::CLFamilly_st:
 				turbulence = 0.2;
 				break;
@@ -290,7 +371,7 @@ void SGEnviro::callback_cloud(float heading, float alt, float radius, int famill
 	// convert to LWC for radar (experimental)
 	// http://www-das.uwyo.edu/~geerts/cwx/notes/chap08/moist_cloud.html
 	double LWC = 0.0;
-	switch(familly) {
+	switch(family) {
 		case SGNewCloud::CLFamilly_st:
 			LWC = 0.29;
 			break;
@@ -324,7 +405,7 @@ void SGEnviro::callback_cloud(float heading, float alt, float radius, int famill
 	// NB:data valid only from cockpit view
 
 	// spawn a new lightning
-	if(lightning_enable_state && min_time_before_lt <= 0.0 && (familly == SGNewCloud::CLFamilly_cb) &&
+	if(lightning_enable_state && min_time_before_lt <= 0.0 && (family == SGNewCloud::CLFamilly_cb) &&
 		dist < 15000.0 * 15000.0 && sg_random() > 0.9f) {
 		double lat, lon;
 		Point3D orig, dest;
@@ -343,7 +424,7 @@ void SGEnviro::callback_cloud(float heading, float alt, float radius, int famill
 //		min_time_before_lt = 5.0;
 	}
 	if( (alt - radius * 0.1) > precipitation_max_alt )
-		switch(familly) {
+		switch(family) {
 			case SGNewCloud::CLFamilly_st:
 			case SGNewCloud::CLFamilly_cu:
 			case SGNewCloud::CLFamilly_cb:
@@ -360,26 +441,25 @@ list_of_SGWxRadarEcho *SGEnviro::get_radar_echo(void) {
 
 // precipitation rendering code
 void SGEnviro::DrawCone2(float baseRadius, float height, int slices, bool down, double rain_norm, double speed) {
-
 	sgVec3 light;
-	sgVec3 min_light = {0.35, 0.35, 0.35};
 	sgAddVec3( light, fog_color, min_light );
 	float da = SG_PI * 2.0f / (float) slices;
 	// low number = faster
-	float speedf = 2.5f - speed / 200.0;
-	if( speedf < 1.0f )
-		speedf = 1.0f;
-	float lenf = 0.03f + speed / 2000.0;
-	if( lenf > 0.10f )
-		lenf = 0.10f;
+	float speedf = streak_period_max - speed * streak_period_change_per_kt;
+	if( speedf < streak_period_min )
+		speedf = streak_period_min;
+	float lenf = streak_length_min + speed * streak_length_change_per_kt;
+	if( lenf > streak_length_max )
+		lenf = streak_length_max;
     float t = fmod((float) elapsed_time, speedf) / speedf;
 //	t = 0.1f;
 	if( !down )
 		t = 1.0f - t;
 	float angle = 0.0f;
-	glColor4f(1.0f, 0.7f, 0.7f, 0.9f);
+	//glColor4f(1.0f, 0.7f, 0.7f, 0.9f); // XXX unneeded? overriden below
 	glBegin(GL_LINES);
-	int rainpos_indice = 0;
+	if (slices >  MAX_RAIN_SLICE)
+		slices = MAX_RAIN_SLICE; // should never happen
 	for( int i = 0 ; i < slices ; i++ ) {
 		float x = cos(angle) * baseRadius;
 		float y = sin(angle) * baseRadius;
@@ -387,12 +467,14 @@ void SGEnviro::DrawCone2(float baseRadius, float height, int slices, bool down,
 		sgVec3 dir = {x, -height, y};
 
 		// rain drops at 2 different speed to simulate depth
-		float t1 = (i & 1 ? t : t + t) + rainpos[rainpos_indice];
+		float t1 = (i & 1 ? t : t + t) + rainpos[i];
 		if(t1 > 1.0f)	t1 -= 1.0f;
 		if(t1 > 1.0f)	t1 -= 1.0f;
 
 		// distant raindrops are more transparent
-		float c = (i & 1 ? t1 * 0.5f : t1 * 0.9f);
+		float c = t1 * (i & 1 ?
+				streak_bright_farmost_layer
+				: streak_bright_nearmost_layer);
 		glColor4f(c * light[0], c * light[1], c * light[2], c);
 		sgVec3 p1, p2;
 		sgScaleVec3(p1, dir, t1);
@@ -402,13 +484,28 @@ void SGEnviro::DrawCone2(float baseRadius, float height, int slices, bool down,
 
 		glVertex3f(p1[0], p1[1] + height, p1[2]);
 		glVertex3f(p2[0], p2[1] + height, p2[2]);
-		if( ++rainpos_indice >= MAX_RAIN_SLICE )
-			rainpos_indice = 0;
 	}
 	glEnd();
 }
 
-void SGEnviro::drawRain(double pitch, double roll, double heading, double speed, double rain_norm) {
+void SGEnviro::drawRain(double pitch, double roll, double heading, double hspeed, double rain_norm) {
+
+#if 0
+	static int debug_period = 0;
+	if (debug_period++ == 50) {
+		debug_period = 0;
+		cout << "drawRain("
+			<< pitch << ", "
+			<< roll  << ", "
+			<< heading << ", "
+			<< hspeed << ", "
+			<< rain_norm << ");"
+			//" angle = " << angle
+			//<< " raindrop(KTS) = " << raindrop_speed_kts
+			<< endl;
+	}
+#endif
+
 
 	glBindTexture(GL_TEXTURE_2D, 0);
 
@@ -419,25 +516,33 @@ void SGEnviro::drawRain(double pitch, double roll, double heading, double speed,
 	glDisable( GL_FOG );
 	glDisable(GL_LIGHTING);
 
-	int slice_count = (40.0 + rain_norm*150.0)* precipitation_density / 100.0;
+	int slice_count = static_cast<int>(
+			(streak_count_min + rain_norm*(streak_count_max-streak_count_min))
+				* precipitation_density / 100.0);
 
-	float angle = speed;
-	if( angle > 90.0 )
-		angle = 90.0;
+	// www.wonderquest.com/falling-raindrops.htm says that
+	// Raindrop terminal velocity is 5 to 20mph
+	// Rather than model it accurately (temp, pressure, diameter), and make it
+	// smaller than terminal when closer to the precipitation cloud base,
+	// we interpolate in the 5-20mph range according to rain_norm.
+	double raindrop_speed_kts
+		= (5.0 + rain_norm*15.0) * SG_MPH_TO_MPS * SG_MPS_TO_KT;
 
+	float angle = atanf(hspeed / raindrop_speed_kts) * SG_RADIANS_TO_DEGREES;
 	glPushMatrix();
-		// TODO:find the real view orientation, not the AC one
-		// the cone rotate with speed
+		// the cone rotate with hspeed
 		angle = -pitch - angle;
+		glRotatef(roll, 0.0, 0.0, 1.0);
+		glRotatef(heading, 0.0, 1.0, 0.0);
 		glRotatef(angle, 1.0, 0.0, 0.0);
-		glRotatef(roll, 0.0, 1.0, 0.0);
-		glRotatef(heading, 0.0, 0.0, 1.0);
 
 		// up cone
-		DrawCone2(15.0, 30.0, slice_count, true, rain_norm, speed);
+		DrawCone2(cone_base_radius, cone_height, 
+				slice_count, true, rain_norm, hspeed);
 		// down cone (usually not visible)
 		if(angle > 0.0 || heading != 0.0)
-			DrawCone2(15.0, -30.0, slice_count, false, rain_norm, speed);
+			DrawCone2(cone_base_radius, -cone_height, 
+					slice_count, false, rain_norm, hspeed);
 
 	glPopMatrix();
 
@@ -452,19 +557,19 @@ void SGEnviro::set_soundMgr(SGSoundMgr *mgr) {
 	soundMgr = mgr;
 }
 
-void SGEnviro::drawPrecipitation(double rain_norm, double snow_norm, double hail_norm, double pitch, double roll, double heading, double speed) {
+void SGEnviro::drawPrecipitation(double rain_norm, double snow_norm, double hail_norm, double pitch, double roll, double heading, double hspeed) {
 	if( precipitation_enable_state && rain_norm > 0.0)
 	  if( precipitation_max_alt >= last_alt )
-		drawRain(pitch, roll, heading, speed, rain_norm);
+		drawRain(pitch, roll, heading, hspeed, rain_norm);
 }
 
 
 SGLightning::SGLightning(double _lon, double _lat, double _alt) :
+	nb_tree(0),
 	lon(_lon),
 	lat(_lat),
 	alt(_alt),
-	age(1.0 + sg_random() * 4.0),
-	nb_tree(0)
+	age(1.0 + sg_random() * 4.0)
 {
 //	sequence_count = 1 + sg_random() * 5.0;
 	lt_build();
@@ -500,7 +605,7 @@ void SGLightning::lt_build_tree_branch(int tree_nr, Point3D &start, float energy
         nseg++;
 		// add a branch
         if( energy * sg_random() > 0.8f )
-			lt_build_tree_branch(tree_nr + 1, pt, energy * 0.9f, nbseg == 50 ? 10 : nbseg * 0.4f, segsize * 0.7f);
+			lt_build_tree_branch(tree_nr + 1, pt, energy * 0.9f, nbseg == 50 ? 10 : static_cast<int>(nbseg * 0.4f), segsize * 0.7f);
 
 		if( nb_tree >= MAX_LT_TREE_SEG )
 			return;
@@ -555,11 +660,12 @@ void SGLightning::lt_Render(void) {
 	sgVec4 c;
 
 #define DRAW_SEG() \
-			{glBegin(GL_LINES); \
+			{glColorMaterial(GL_FRONT, GL_EMISSION);  \
+			glDisable(GL_LINE_SMOOTH); glBegin(GL_LINES); \
 				glColor4fv(c); \
                 glVertex3f(lt_tree[n].pt[PX], lt_tree[n].pt[PZ], lt_tree[n].pt[PY]); \
                 glVertex3f(lt_tree[lt_tree[n].prev].pt[PX], lt_tree[lt_tree[n].prev].pt[PZ], lt_tree[lt_tree[n].prev].pt[PY]); \
-			glEnd();}
+			glEnd(); glEnable(GL_LINE_SMOOTH);}
 
 	glDepthMask( GL_FALSE );
 	glEnable(GL_BLEND);
@@ -654,7 +760,7 @@ void SGEnviro::drawLightning(void) {
 				double ax = 0.0, ay = 0.0;
 				ax = cos(course) * dist;
 				ay = sin(course) * dist;
-				SGSoundSample *snd = soundMgr->find("thunder");
+				SGSharedPtr<SGSoundSample> snd = soundMgr->find("thunder");
 				if( snd ) {
 					ALfloat pos[3]={ax, ay, -sgEnviro.last_alt };
 					snd->set_source_pos(pos);
