@@ -15,19 +15,23 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Library General Public License for more details.
 //
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA  02111-1307, USA.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: sg_path.cxx,v 1.12 2004/11/19 21:44:16 curt Exp $
+// $Id: sg_path.cxx,v 1.21 2006-03-08 18:16:08 mfranz Exp $
 
 
 #include <simgear/compiler.h>
 
 #include <simgear_config.h>
+#include <simgear/debug/logstream.hxx>
 #include <stdio.h>
-
+#include <sys/stat.h>
+#include <sys/stat.h>
+#if defined( _MSC_VER) || defined(__MINGW32__)
+#  include <direct.h>
+#endif
 #include "sg_path.hxx"
 
 
@@ -182,6 +186,67 @@ bool SGPath::exists() const {
     return true;
 }
 
+#if defined( _MSC_VER) || defined(__MINGW32__)
+#  define sgMkDir(d,m)       _mkdir(d)
+#else
+#  define sgMkDir(d,m)       mkdir(d,m)
+#endif
+
+
+void SGPath::create_dir( mode_t mode ) {
+    string_list dirlist = sgPathSplit(dir());
+    string path = dirlist[0];
+    string_list path_elements = sgPathBranchSplit(path);
+    bool absolute = !path.empty() && path[0] == sgDirPathSep;
+
+    unsigned int i = 1;
+    SGPath dir = absolute ? string( 1, sgDirPathSep ) : "";
+    dir.concat( path_elements[0] );
+#if defined( _MSC_VER) || defined(__MINGW32__)
+    if ( dir.str().find(':') != string::npos && path_elements.size() >= 2 ) {
+        dir.append( path_elements[1] );
+        i = 2;
+    }
+#endif
+    struct stat info;
+    int r;
+    for(; ( r = stat( dir.c_str(), &info ) ) == 0 && i < path_elements.size(); i++) {
+        dir.append(path_elements[i]);
+    }
+    if ( r == 0 ) {
+        return; // Directory already exists
+    }
+    if ( sgMkDir( dir.c_str(), mode) ) {
+        SG_LOG( SG_IO, SG_ALERT, "Error creating directory: " + dir.str() );
+        return;
+    }
+    for(;i < path_elements.size(); i++) {
+        dir.append(path_elements[i]);
+        if ( sgMkDir( dir.c_str(), mode) ) {
+            SG_LOG( SG_IO, SG_ALERT, "Error creating directory: " + dir.str() );
+            break;
+        }
+    }
+}
+
+string_list sgPathBranchSplit( const string &dirpath ) {
+    string_list path_elements;
+    string element, path = dirpath;
+    while ( path.size() ) {
+        size_t p = path.find( sgDirPathSep );
+        if ( p != string::npos ) {
+            element = path.substr( 0, p );
+            path.erase( 0, p + 1 );
+        } else {
+            element = path;
+            path = "";
+        }
+        if ( element.size() )
+            path_elements.push_back( element );
+    }
+    return path_elements;
+}
+
 
 string_list sgPathSplit( const string &search_path ) {
     string tmp = search_path;
