@@ -1,6 +1,3 @@
-#ifdef _MSC_VER
-#define _USE_MATH_DEFINES
-#endif
 
 #include <math.h>
 #include <string.h>
