@@ -245,7 +245,8 @@ static void makeDList( ssgBranch *b, const set<ssgBranch *> &ignore )
 ssgBranch *
 sgLoad3DModel( const string &fg_root, const string &path,
                SGPropertyNode *prop_root,
-               double sim_time_sec, ssgEntity *(*load_panel)(SGPropertyNode *) )
+               double sim_time_sec, ssgEntity *(*load_panel)(SGPropertyNode *),
+               SGModelData *data )
 {
   ssgBranch * model = 0;
   SGPropertyNode props;
@@ -283,7 +284,8 @@ sgLoad3DModel( const string &fg_root, const string &path,
     ssgTexturePath((char *)texturepath.c_str());
     model = (ssgBranch *)ssgLoad((char *)modelpath.c_str());
     if (model == 0)
-      throw sg_exception("Failed to load 3D model");
+      throw sg_io_exception("Failed to load 3D model", 
+			  sg_location(modelpath.str()));
   }
                                 // Set up the alignment node
   ssgTransform * alignmainmodel = new ssgTransform;
@@ -317,8 +319,15 @@ sgLoad3DModel( const string &fg_root, const string &path,
                         node->getFloatValue("offsets/z-m", 0.0));
     align->setTransform(res_matrix);
 
-    ssgBranch * kid = sgLoad3DModel( fg_root, node->getStringValue("path"),
-                                     prop_root, sim_time_sec, load_panel );
+    ssgBranch * kid;
+    const char * submodel = node->getStringValue("path");
+    try {
+      kid = sgLoad3DModel( fg_root, submodel, prop_root, sim_time_sec, load_panel );
+
+    } catch (const sg_throwable &t) {
+      SG_LOG(SG_INPUT, SG_ALERT, "Failed to load submodel: " << t.getFormattedMessage());
+      throw;
+    }
     align->addKid(kid);
     align->setName(node->getStringValue("name", ""));
     model->addKid(align);
@@ -335,6 +344,11 @@ sgLoad3DModel( const string &fg_root, const string &path,
         model->addKid(panel);
     }
   }
+
+  if (data) {
+    alignmainmodel->setUserData(data);
+    data->modelLoaded(path, &props, alignmainmodel);
+  }
                                 // Load animations
   set<ssgBranch *> ignore_branches;
   vector<SGPropertyNode_ptr> animation_nodes = props.getChildren("animation");
@@ -352,6 +366,9 @@ sgLoad3DModel( const string &fg_root, const string &path,
   }
 #endif
 
+  int m = props.getIntValue("dump", 0);
+  if (m > 0)
+    model->print(stderr, "", m - 1);
 
   return alignmainmodel;
 }
