@@ -16,10 +16,13 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 //
 
+#ifdef HAVE_CONFIG_H
+#  include <simgear_config.h>
+#endif
 
 #include <plib/sg.h>
 #include <plib/ssg.h>
@@ -213,7 +216,7 @@ static int heat_haze_shader_callback( ssgEntity *e ) {
         sgMat4 CameraProjM, CameraViewM;
         glGetFloatv(GL_PROJECTION_MATRIX, (GLfloat *) CameraProjM);
         glGetFloatv(GL_MODELVIEW_MATRIX, (GLfloat *) CameraViewM);
-        const float dummy_scale = 1.0f; //0.95f;
+        // const float dummy_scale = 1.0f; //0.95f;
         const float deltaPos = 0.05f;
         glMatrixMode(GL_TEXTURE);
             glLoadIdentity();
@@ -268,7 +271,7 @@ static int heat_haze_shader_callback( ssgEntity *e ) {
         glCallList ( dlist ) ;
 
         // alter colors only on last rendering
-        sgVec4 fLight = {0.93f, 0.93f, 1.00f, 0.85f};
+        // sgVec4 fLight = {0.93f, 0.93f, 1.00f, 0.85f};
         glTexEnvi( GL_TEXTURE_ENV, GL_SOURCE1_RGB_ARB, GL_PRIMARY_COLOR_ARB );
         glTexEnvi( GL_TEXTURE_ENV, GL_OPERAND1_RGB_ARB, GL_SRC_COLOR ); 
 
@@ -328,7 +331,7 @@ static int fresnel_shader_callback( ssgEntity *e ) {
     ssgGetLight( 0 )->getColour(GL_DIFFUSE, sunColor );
     ssgGetLight( 0 )->getColour(GL_AMBIENT, ambientColor );
 
-    SGShaderAnimation *my_shader = (SGShaderAnimation *) ( e->getUserData() );
+    // SGShaderAnimation *my_shader = (SGShaderAnimation *) ( e->getUserData() );
     glEnable(GL_BLEND);
 	glBlendFunc ( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA) ;
 	glEnable(GL_ALPHA_TEST);
