@@ -16,10 +16,14 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 //
 
+#ifdef HAVE_CONFIG_H
+#  include <simgear_config.h>
+#endif
+
 #include <plib/sg.h>
 #include <plib/ssg.h>
 #include <simgear/props/props.hxx>
@@ -100,8 +104,8 @@ SGShadowVolume::ShadowCaster::ShadowCaster( int _num_tri, ssgBranch * _geometry_
 	scenery_object ( 0 ),
 	first_select ( 0 ),
 	frameNumber ( 0 ),
-	numTriangles ( 0 ),
 	indices ( 0 ),
+	numTriangles ( 0 ),
 	vertices ( 0 ),
 	lastSilhouetteIndicesCount ( 0 )
 {
@@ -638,7 +642,7 @@ static bool filterLeaf(ssgLeaf *this_kid) {
 	if( ! leaf_name )
 		return true;
 	char lname[20];
-	int l = 0;
+	unsigned int l = 0;
 	char *buff;
 	for( buff = lname; *leaf_name && l < (sizeof( lname )-1); ++buff, l++ )
 	     *buff = tolower(*leaf_name++);
@@ -702,9 +706,9 @@ void SGShadowVolume::SceneryObject::find_trans(void) {
 }
 
 SGShadowVolume::SceneryObject::SceneryObject(ssgBranch *_scenery_object, OccluderType _occluder_type) :
-	pending_object ( _scenery_object ),
-	occluder_type ( _occluder_type ),
-	scenery_object ( 0 )
+        scenery_object ( 0 ),
+        pending_object ( _scenery_object ),
+        occluder_type ( _occluder_type )
 {
 	// queue objects, don't do all the work in the first frames because of
 	// massive cpu power needed
@@ -901,7 +905,6 @@ void SGShadowVolume::deleteOccluderFromTile(ssgBranch *tile) {
 }
 
 void SGShadowVolume::deleteOccluder(ssgBranch *occluder) {
-	ssgBranch *branch = occluder;
 	// skip first node and go to first transform (placement)
 	while( occluder && !occluder->isA(ssgTypeTransform()))
 		occluder = (ssgBranch *) occluder->getKid(0);
@@ -915,9 +918,6 @@ void SGShadowVolume::deleteOccluder(ssgBranch *occluder) {
 }
 
 void SGShadowVolume::addOccluder(ssgBranch *occluder, OccluderType occluder_type, ssgBranch *tile) {
-
-	ssgBranch *branch = occluder;
-
 	// skip first node and go to first transform (placement)
 	while( occluder && !occluder->isA(ssgTypeTransform()))
 		occluder = (ssgBranch *) occluder->getKid(0);
