@@ -16,10 +16,13 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: apt_signs.cxx,v 1.3 2004/11/19 21:44:17 curt Exp $
+// $Id: apt_signs.cxx,v 1.5 2006-03-08 18:16:09 mfranz Exp $
 
+#ifdef HAVE_CONFIG_H
+#  include <simgear_config.h>
+#endif
 
 #include <simgear/debug/logstream.hxx>
 #include <simgear/math/sg_types.hxx>
