@@ -16,10 +16,13 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: sample_openal.cxx,v 1.23 2005/11/12 12:22:23 ehofman Exp $
+// $Id: sample_openal.cxx,v 1.26 2006-03-08 18:16:09 mfranz Exp $
 
+#ifdef HAVE_CONFIG_H
+#  include <simgear_config.h>
+#endif
 
 #if defined( __APPLE__ )
 # define AL_ILLEGAL_ENUM AL_INVALID_ENUM
@@ -118,7 +121,8 @@ SGSoundSample::SGSoundSample( const char *path, const char *file) :
   if (buffer == AL_NONE) {
      ALenum error = alutGetError ();
      print_openal_error("constructor (alutCreateBufferFromFile)");
-     throw sg_exception("Failed to load wav file: "+string(alutGetErrorString (error)));
+     throw sg_io_exception("Failed to load wav file: ",
+			 sg_location(string(alutGetErrorString (error))));
   }
 
 #else
@@ -383,7 +387,8 @@ SGSoundSample::load_file(const char *path, const char *file)
     ALfloat freqf;
     data = alutLoadMemoryFromFile(samplepath.c_str(), &format, &size, &freqf );
     if (data == NULL) {
-        throw sg_exception("Failed to load wav file.");
+        throw sg_io_exception("Failed to load wav file.",
+					sg_location(samplepath.str()));
     }
     freq = (ALsizei)freqf;
 #else
@@ -395,7 +400,8 @@ SGSoundSample::load_file(const char *path, const char *file)
                      &format, &data, &size, &freq, &loop );
 # endif
     if ( print_openal_error("constructor (alutLoadWAVFile)") ) {
-        throw sg_exception("Failed to load wav file.");
+        throw sg_io_exception("Failed to load wav file.",
+					sg_location(samplepath.str()));
     }
 #endif
 
