@@ -17,9 +17,9 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: xmlsound.cxx,v 1.13 2005/11/12 10:26:21 ehofman Exp $
+// $Id: xmlsound.cxx,v 1.17 2006-03-08 18:16:09 mfranz Exp $
 
 #include <simgear/compiler.h>
 
@@ -38,12 +38,13 @@
 #include "xmlsound.hxx"
 
 
+#define LOG_ABS(x) (((x) > 1) ? (x) : (((x) < -1) ? -(x) : 0))
 // static double _snd_lin(double v)   { return v; }
 static double _snd_inv(double v)   { return (v == 0) ? 1e99 : 1/v; }
 static double _snd_abs(double v)   { return (v >= 0) ? v : -v; }
 static double _snd_sqrt(double v)  { return (v < 0) ? sqrt(-v) : sqrt(v); }
-static double _snd_log10(double v) { return (v < 1) ? 0 : fast_log10(v); }
-static double _snd_log(double v)   { return (v < 1) ? 0 : fast_log(v); }
+static double _snd_log10(double v) { return fast_log10( LOG_ABS(v) ); }
+static double _snd_log(double v)   { return fast_log( LOG_ABS(v) ); }
 // static double _snd_sqr(double v)   { return v*v; }
 // static double _snd_pow3(double v)  { return v*v*v; }
 
@@ -65,7 +66,6 @@ static const struct {
 SGXmlSound::SGXmlSound()
   : _sample(NULL),
     _condition(NULL),
-    _property(NULL),
     _active(false),
     _name(""),
     _mode(SGXmlSound::ONCE),
@@ -78,14 +78,13 @@ SGXmlSound::SGXmlSound()
 
 SGXmlSound::~SGXmlSound()
 {
-    _sample->stop();
+    if (_sample)
+        _sample->stop();
 
-    delete _property;
     delete _condition;
 
     _volume.clear();
     _pitch.clear();
-    delete _sample;
 }
 
 void
